Structs
Enums
Functions
- parse_
distance - How many branches an
up/downshould move. Zero lands where you already are and the other direction is the other command’s job, so neither is a distance.
up/down should move. Zero lands where you already
are and the other direction is the other command’s job, so neither is a
distance.