pub enum Command {
Show 19 variants
New {
branch: String,
},
Parent {
branch: Option<String>,
},
Children {
branch: Option<String>,
},
Up,
Down {
branch: Option<String>,
},
List,
Status {
branch: Option<String>,
},
Adopt {
branch: String,
parent: String,
},
Detach {
branch: Option<String>,
},
Restack {
update_refs: bool,
no_update_refs: bool,
},
Continue,
Abort,
Provider,
Review {
branch: Option<String>,
},
Sync {
branch: Option<String>,
dry_run: bool,
},
Submit {
branch: Option<String>,
dry_run: bool,
stack: bool,
},
Completions {
shell: Shell,
},
Upgrade {
head: bool,
force: bool,
yes: bool,
},
Cleanup {
branch: Option<String>,
dry_run: bool,
delete_branch: bool,
},
}Variants
New
Create a new child branch from the current branch.
Parent
Print a branch’s stack parent.
Children
Print a branch’s stack children.
Up
Check out the current branch’s stack parent.
Down
Check out a stack child of the current branch.
List
Print the current stack.
Status
Print local and remote stack status for a branch.
Adopt
Attach an existing branch to a parent.
Detach
Remove stack parent metadata from a branch.
Restack
Rebase the current branch and descendants onto their stack parents.
Fields
Continue
Continue an interrupted restack after resolving conflicts.
Abort
Abort an interrupted restack.
Provider
Print detected review provider.
Review
Print the review request for a branch.
Sync
Sync local stack metadata from remote review requests.
Submit
Create or update a remote review request for a branch.
Fields
Completions
Print shell completions.
Upgrade
Upgrade git-stk to the latest release.
Fields
Cleanup
Clean up local metadata for merged review requests.