cherry_pick

Function cherry_pick 

pub fn cherry_pick(commit: &str) -> Result<()>
Cherry-pick a commit onto the current branch. On conflict git leaves the cherry-pick in progress, so the error surfaces for the caller to tell the user to resolve and git cherry-pick --continue.