read_ref_file

Function read_ref_file 

pub fn read_ref_file(reference: &str, file: &str) -> Result<Option<String>>
The contents of file in the commit reference points at, or None when the ref or file is absent.