checkout_top

Function checkout_top 

pub fn checkout_top(output: NavOutput) -> Result<()>
Check out the leaf of the current stack, following single children. A fork is ambiguous, like up without a branch.