record_base

Function record_base 

pub fn record_base(branch: &str, parent: &str)
Record the fork point between a branch and its parent (best effort; e.g. unrelated histories have no merge base, which is not an error here).