set_renamed_from

Function set_renamed_from 

pub fn set_renamed_from(branch: &str, old: &str) -> Result<()>
Record that branch is the rename of old, whose open review the next submit should replace and close.