Command

Enum Command 

pub enum Command {
Show 18 variants New { branch: String, }, Parent { branch: Option<String>, }, Children { branch: Option<String>, }, Up, Down { branch: Option<String>, }, List, Status { branch: Option<String>, }, Adopt { branch: String, parent: String, }, Detach { branch: Option<String>, }, Restack { update_refs: bool, no_update_refs: bool, }, Continue, Abort, Provider, Review { branch: Option<String>, }, Sync { branch: Option<String>, dry_run: bool, }, Submit { branch: Option<String>, dry_run: bool, stack: bool, }, Upgrade { head: bool, force: bool, yes: bool, }, Cleanup { branch: Option<String>, dry_run: bool, delete_branch: bool, },
}

Variants



New

Create a new child branch from the current branch.

Fields

branch: String


Parent

Print a branch’s stack parent.

Fields

branch: Option<String>


Children

Print a branch’s stack children.

Fields

branch: Option<String>


Up

Check out the current branch’s stack parent.



Down

Check out a stack child of the current branch.

Fields

branch: Option<String>


List

Print the current stack.



Status

Print local and remote stack status for a branch.

Fields

branch: Option<String>


Adopt

Attach an existing branch to a parent.

Fields

branch: String
parent: String


Detach

Remove stack parent metadata from a branch.

Fields

branch: Option<String>


Restack

Rebase the current branch and descendants onto their stack parents.

Fields

update_refs: bool

Pass –update-refs to git rebase.

no_update_refs: bool

Do not pass –update-refs to git rebase.



Continue

Continue an interrupted restack after resolving conflicts.



Abort

Abort an interrupted restack.



Provider

Print detected review provider.



Review

Print the review request for a branch.

Fields

branch: Option<String>


Sync

Sync local stack metadata from remote review requests.

Fields

branch: Option<String>
dry_run: bool

Print what would change without updating local metadata.



Submit

Create or update a remote review request for a branch.

Fields

branch: Option<String>
dry_run: bool

Print what would change without creating or updating reviews.

stack: bool

Submit the branch and its descendants parent-first.



Upgrade

Upgrade git-stk to the latest release.

Fields

head: bool

Build and install the latest unreleased commit instead.

force: bool

Reinstall the latest release even when already up to date.

yes: bool

Skip the –head confirmation prompt.



Cleanup

Clean up local metadata for merged review requests.

Fields

branch: Option<String>
dry_run: bool

Print what would change without updating local metadata.

delete_branch: bool

Delete cleaned merged branches after updating stack metadata.