Module git

Module git 

Functions

checkout
config_get
config_get_bool
config_set
config_unset
create_branch
current_branch
delete_branch
git_path
is_ancestor
local_branches
merge_base
rebase
rebase_abort
rebase_continue
rebase_onto
Rebase only the commits after base, replaying base..branch onto parent. Used when the recorded fork point is known so commits that landed upstream by squash or rebase are not replayed.
remote_url
supports_rebase_update_refs