Functions
- checkout
- config_
get - config_
get_ bool - config_
set - config_
unset - create_
branch - current_
branch - delete_
branch - git_
path - is_
ancestor - local_
branches - merge_
base - rebase
- rebase_
abort - rebase_
continue - rebase_
onto - Rebase only the commits after
base, replayingbase..branchontoparent. Used when the recorded fork point is known so commits that landed upstream by squash or rebase are not replayed. - remote_
url - supports_
rebase_ update_ refs