worktree_dir

Function worktree_dir 

pub fn worktree_dir() -> Result<PathBuf>
Where new --worktree puts a branch’s worktree. From stk.worktreeDir, or a sibling of the repo root named <repo>-worktrees - outside the repo, so the worktrees do not land in its own file watchers, ignore rules, or git status.