Functions
- abort_
restack - adopt_
branch - base_
for_ branch - branch_
and_ descendants - checkout_
child - checkout_
parent - children_
for_ branch - continue_
restack - create_
branch - detach_
branch - parent_
for_ branch - print_
children - print_
parent - print_
stack - record_
base - Record the fork point between a branch and its parent (best effort; e.g. unrelated histories have no merge base, which is not an error here).
- restack
- set_
base_ for_ branch - set_
parent_ for_ branch - stack_
root - The root of the stack containing
branch(the base everything sits on). - trunk_
branch - The trunk branch: the remote’s default branch when known locally, otherwise a conventional name that exists.
- unset_
base_ for_ branch - unset_
parent_ for_ branch